package v1

import (
	"property-company-gateway/param/base"
	pb_v1 "property-company-gateway/pb/v1"
)

type CompanyRegisterBody struct {
	// 申请人
	Applicant string `form:"applicant" json:"applicant"`
	// 申请人电话
	ApplicantPhone string `form:"applicant_phone" json:"applicant_phone"`
	// 公司名称
	CompanyName string `form:"company_name" json:"company_name"`
	// 公司电话
	CompanyPhone string `form:"company_phone" json:"company_phone"`
	// 申请人职位
	ApplicantDuty string `form:"applicant_duty" json:"applicant_duty"`
	// 法人
	LegalPerson string `form:"legal_person" json:"legal_person"`
	// 公司地址
	CompanyAddr string `form:"company_addr" json:"company_addr"`
	// 社会信用码
	SocialCode string `form:"social_code" json:"social_code"`
	// 营业执照
	BusinessLicense string `form:"business_license" json:"business_license"`
	// 申请人身份
	ApplicantIdentification string `form:"applicant_identification" json:"applicant_identification"`
	// 营业执照类型
	LicenseType int32 `form:"license_type" json:"license_type"`
	// 免费小区个数
	FreeGardenCount int32 `form:"free_garden_count" json:"free_garden_count"`
	// 账户名
	Username string `form:"username" json:"username"`
	// 密码
	Password string `form:"password" json:"password"`

	// 公司logo
	Logo string `form:"logo" json:"logo"`
	// 简介
	Desc string `form:"desc" json:"desc"`
	// 网址
	Site string `form:"site" json:"site"`
}

type CompanyRegisterRequest struct {
	CompanyRegisterBody
}

type CompanyRegisterResponse struct {
	base.Result
	Data pb_v1.RegisterReply `json:"data"`
}

type CompanyInfoRequest struct {
	base.Header
}

type CompanyInfoResponse struct {
	base.Result
	Data pb_v1.CompanyInfoReply `json:"data"`
}

type CompanyUpdateBody struct {
	// 公司名称
	CompanyName string `form:"company_name" json:"company_name"`
	// 公司电话
	CompanyPhone string `form:"company_phone" json:"company_phone"`
	// 公司地址
	CompanyAddr string `form:"company_addr" json:"company_addr"`
	// 社会信用码
	SocialCode string `form:"social_code" json:"social_code"`
	// 营业执照
	BusinessLicense string `form:"business_license" json:"business_license"`
	// 营业执照类型
	LicenseType int32 `form:"license_type" json:"license_type"`
	// 公司logo
	Logo string `form:"logo" json:"logo"`
	// 简介
	Desc string `form:"desc" json:"desc"`
	// 网址
	Site string `form:"site" json:"site"`
}
type CompanyUpdateRequest struct {
	base.Header
	CompanyUpdateBody
}

type CompanyUpdateResponse struct {
	base.Result
}

type CompanyWxBusinessLicenseInfo struct {
	// 营业执照mediaid,调upload_wx接口获取 必填
	LicenseCopy string `form:"license_copy" json:"license_copy"`
	// 统一社会信用码 必填
	LicenseNumber string `form:"license_number" json:"license_number"`
	// 营业执照上的商户名称 必填
	MerchantName string `form:"merchant_name" json:"merchant_name"`
	// 法人姓名 必填
	LegalPerson string `form:"legal_person" json:"legal_person"`
	// 证书的注册地址 必填
	LicenseAddress string `form:"license_address" json:"license_address"`
	// 有效期限开始日期 yyyy-mm-dd格式 必填
	PeriodBegin string `form:"period_begin" json:"period_begin"`
	// 有效期限结束日期， yyyy-mm-dd格式，如果是长期则填长期 必填
	PeriodEnd string `form:"period_end" json:"period_end"`
	// 营业执照url, 调upload_wx接口获取 必填
	LicenseCopyUrl string `form:"license_copy_url" json:"license_copy_url"`
}

type CompanyWxIdCardInfo struct {
	// 身份证人像面照片mediaid,调upload_wx接口获取 必填
	IdCardCopy string `form:"id_card_copy" json:"id_card_copy"`
	// 身份证国徽面照片mediaid,调upload_wx接口获取 必填
	IdCardNational string `form:"id_card_national" json:"id_card_national"`
	// 身份证号码 必填
	IdCardNumber string `form:"id_card_number" json:"id_card_number"`
	// 有效期开始时间 必填
	CardPeriodBegin string `form:"card_period_begin" json:"card_period_begin"`
	// 有效期限结束日期， yyyy-mm-dd格式，如果是长期则填长期 必填
	CardPeriodEnd string `form:"card_period_end" json:"card_period_end"`
	// 身份证姓名 必填
	IdCardName string `form:"id_card_name" json:"id_card_name"`
	// 证件地址 必填
	IdCardAddress string `form:"id_card_address" json:"id_card_address"`

	// 身份证人像面照片url,调upload_wx接口获取 必填
	IdCardCopyUrl string `form:"id_card_copy_url" json:"id_card_copy_url"`
	// 身份证国徽面照片url,调upload_wx接口获取 必填
	IdCardNationalUrl string `form:"id_card_national_url" json:"id_card_national_url"`
}

type CompanyWxIdDocInfo struct {
	// 证件类型 必填
	// IDENTIFICATION_TYPE_IDCARD：中国大陆居民-身份证
	// IDENTIFICATION_TYPE_OVERSEA_PASSPORT：其他国家或地区居民-护照
	// IDENTIFICATION_TYPE_HONGKONG_PASSPORT：中国香港居民-来往内地通行证
	// IDENTIFICATION_TYPE_MACAO_PASSPORT：中国澳门居民-来往内地通行证
	// IDENTIFICATION_TYPE_TAIWAN_PASSPORT：中国台湾居民-来往大陆通行证
	IdDocType string `form:"id_doc_type" json:"id_doc_type"`
	// 证件正面图片mediaid,调upload_wx接口获取 必填
	IdDocCopy string `form:"id_doc_copy" json:"id_doc_copy"`
	// 证件背面图片mediaid,调upload_wx接口获取, 当证件类型为护照时，该字段为空，其他情况必填
	IdDocCopyBack string `form:"id_doc_copy_back" json:"id_doc_copy_back"`
	// 证件正面图片url,调upload_wx接口获取 必填
	IdDocCopyUrl string `form:"id_doc_copy_url" json:"id_doc_copy_url"`
	// 证件背面图片url,调upload_wx接口获取，当证件类型为护照时，该字段可为空，其他情况必填
	IdDocCopyBackUrl string `form:"id_doc_copy_back_url" json:"id_doc_copy_back_url"`
	// 证件姓名 必填
	IdDocName string `form:"id_doc_name" json:"id_doc_name"`
	// 证件号 必填
	IdDocNumber string `form:"id_doc_number" json:"id_doc_number"`
	// 开始时间 必填
	DocPeriodBegin string `form:"doc_period_begin" json:"doc_period_begin"`
	// 结束时间 必填
	DocPeriodEnd string `form:"doc_period_end" json:"doc_period_end"`
	// 证件地址 必填
	IdDocAddress string `form:"id_doc_address" json:"id_doc_address"`
}

type CompanyWxIdentityInfo struct {
	// 固定写死 LEGAL, 必填
	IdHolderType string `form:"id_holder_type" json:"id_holder_type"`

	// 目前直接写死传空字符串
	// 法定代表人说明函图片mediaid 调upload_wx接口获取
	// 1、当证件持有人类型为经办人时，必须上传。其他情况，无需上传。
	// 2、若因特殊情况，无法提供法定代表人证件时，请参照示例图打印法定代表人说明函，全部信息需打印，不支持手写商户信息，并加盖公章。
	// 3、可上传1张图片，请填写通过图片上传APIAPI预先上传图片生成好的MediaID。
	AuthorizeLetterCopy string `form:"authorize_letter_copy" json:"authorize_letter_copy"`
	//  目前直接写死传空字符串
	// 法定代表人说明函图片url  调upload_wx接口获取
	AuthorizeLetterCopyUrl string `form:"authorize_letter_copy_url" json:"authorize_letter_copy_url"`

	// 证件信息
	IdDocInfo CompanyWxIdDocInfo `form:"id_doc_info" json:"id_doc_info"`
	// 法人是否为最终受益人 必填
	Owner bool `form:"owner" json:"owner"`
}

type CompanyWxUboInfo struct {
	// 必填
	// IDENTIFICATION_TYPE_IDCARD：中国大陆居民-身份证
	// IDENTIFICATION_TYPE_OVERSEA_PASSPORT：其他国家或地区居民-护照
	// IDENTIFICATION_TYPE_HONGKONG_PASSPORT：中国香港居民-来往内地通行证
	// IDENTIFICATION_TYPE_MACAO_PASSPORT：中国澳门居民-来往内地通行证
	// IDENTIFICATION_TYPE_TAIWAN_PASSPORT：中国台湾居民-来往大陆通行证
	UboIdDocType string `form:"ubo_id_doc_type" json:"ubo_id_doc_type"`
	// 收益人证件正面mediaid,调upload_wx接口获取 必填
	UboIdDocCopy string `form:"ubo_id_doc_copy" json:"ubo_id_doc_copy"`
	// 背面mediaid,调upload_wx接口获取,护照不填该字段
	UboIdDocCopyBack string `form:"ubo_id_doc_copy_back" json:"ubo_id_doc_copy_back"`
	// 证件居住地址 必填
	UboIdDocAddress string `form:"ubo_id_doc_address" json:"ubo_id_doc_address"`
	// 受益人姓名 必填
	UboIdDocName string `form:"ubo_id_doc_name" json:"ubo_id_doc_name"`
	// 证件号码 必填
	UboIdDocNumber string `form:"ubo_id_doc_number" json:"ubo_id_doc_number"`
	// 开始时间 必填
	UboPeriodBegin string `form:"ubo_period_begin" json:"ubo_period_begin"`
	// 结束时间 必填
	UboPeriodEnd string `form:"ubo_period_end" json:"ubo_period_end"`
	// 收益人证件正面url,调upload_wx接口获取 必填
	UboIdDocCopyUrl string `form:"ubo_id_doc_copy_url" json:"ubo_id_doc_copy_url"`
	// 背面url,调upload_wx接口获取 护照不填该字段
	UboIdDocCopyBackUrl string `form:"ubo_id_doc_copy_back_url" json:"ubo_id_doc_copy_back_url"`
}

type CompanyWxSubjectInfo struct {
	// 主体类型 必填， 写死为SUBJECT_TYPE_ENTERPRISE
	// 主体类型需与营业执照/登记证书上一致，可参考选择主体指引
	// SUBJECT_TYPE_INDIVIDUAL（个体户）：营业执照上的主体类型一般为个体户、个体工商户、个体经营；
	// SUBJECT_TYPE_ENTERPRISE（企业）：营业执照上的主体类型一般为有限公司、有限责任公司；
	// SUBJECT_TYPE_INSTITUTIONS（党政、机关及事业单位）：包括国内各级、各类政府机构、事业单位等（如：公安、党团、司法、交通、旅游、工商税务、市政、医疗、教育、学校等机构）；
	// SUBJECT_TYPE_OTHERS（其他组织）：不属于企业、政府/事业单位的组织机构（如社会团体、民办非企业、基金会），要求机构已办理组织机构代码证。
	SubjectType string `form:"subject_type" json:"subject_type"`
	// 营业执照信息 必填
	BusinessLicenseInfo CompanyWxBusinessLicenseInfo `form:"business_license_info" json:"business_license_info"`
	// 法人身份信息 必填
	IdentityInfo CompanyWxIdentityInfo `form:"identity_info" json:"identity_info"`
	// 受益人身份信息，若法人不是最终受益人，则该字段必填
	// 若经营者/法人不是最终受益所有人，则需提填写受益所有人信息。
	// 根据国家相关法律法规，需要提供公司受益所有人信息，受益所有人需符合至少以下条件之一：
	// 1、直接或者间接拥有超过25%公司股权或者表决权的自然人。
	// 2、通过人事、财务等其他方式对公司进行控制的自然人。
	// 3、公司的高级管理人员，包括公司的经理、副经理、财务负责人、上市公司董事会秘书和公司章程规定的其他人员。
	UboInfos []CompanyWxIdDocInfo `form:"ubo_infos" json:"ubo_infos"`
}
type CompanyWxBusinessInfo struct {
	// 商户简称 必填
	// 1、请输入2-30个字符，支持中文/字母/数字/特殊符号
	// 2、在支付完成页向买家展示，需与微信经营类目相关；
	// 3、简称要求
	//    （1）不支持单纯以人名来命名，若为个体户经营，可用“个体户+经营者名称”或“经营者名称+业务”命名，如“个体户张三”或“张三餐饮店”；
	//    （2）不支持无实际意义的文案，如“XX特约商户”、“800”、“XX客服电话XXX”；
	MerchantShortname string `form:"merchant_shortname" json:"merchant_shortname"`
	// 客服电话 必填
	ServicePhone string `form:"service_phone" json:"service_phone"`
}
type CompanyWxBankAccountInfo struct {
	// 开户姓名, 开户名称必须与营业执照/登记证书的“商户名称”一致 必填
	AccountName string `form:"account_name" json:"account_name"`
	// 开户行 必填 开户银行，传参规则如下：
	//1、17家直连银行，请根据开户银行对照表直接填写银行名 ;
	//2、非17家直连银行，该参数请填写为“其他银行”。
	//
	AccountBank string `form:"account_bank" json:"account_bank"`
	// 开户银行省市编码
	BankAddressCode string `form:"bank_address_code" json:"bank_address_code"`
	// 开户银行全称（含支行）必填
	//示例值：中国银行股份有限公司成都鹭洲里支行
	BankName string `form:"bank_name" json:"bank_name"`
	// 银行账号 必填
	AccountNumber string `form:"account_number" json:"account_number"`
	// 写死为 BANK_ACCOUNT_TYPE_CORPORATE
	BankAccountType string `protobuf:"bytes,7,opt,name=bank_account_type,json=bankAccountType,proto3" json:"bank_account_type"`
}

type CompanyWxContactInfo struct {
	// LEGAL：经营者/法人，SUPER：经办人 。必填
	ContactType string `form:"contact_type" json:"contact_type"`
	// 联系人姓名 必填
	ContactName string `form:"contact_name" json:"contact_name"`
	// 联系人证件类型（当为经办人时才填）
	ContactIdDocType string `form:"contact_id_doc_type" json:"contact_id_doc_type"`
	// 证件号（当为经办人时才填）
	ContactIdNumber string `form:"contact_id_number" json:"contact_id_number"`
	// 证件正面图片mediaid,调upload_wx接口获取（当为经办人时才填）
	ContactIdDocCopy string `form:"contact_id_doc_copy" json:"contact_id_doc_copy"`
	// 证件背面图片mediaid,调upload_wx接口获取（当为经办人时才填）护照不填该字段
	ContactIdDocCopyBack string `form:"contact_id_doc_copy_back" json:"contact_id_doc_copy_back"`
	// 证件开始时间（当为经办人时才填）
	ContactPeriodBegin string `form:"contact_period_begin" json:"contact_period_begin"`
	// 证件结束时间（当为经办人时才填）
	ContactPeriodEnd string `form:"contact_period_end" json:"contact_period_end"`
	// 授权函mediaid,调upload_wx接口获取（当为经办人时才填）
	BusinessAuthorizationLetter string `form:"business_authorization_letter" json:"business_authorization_letter"`
	// 授权函 url,调upload_wx接口获取
	BusinessAuthorizationLetterUrl string `form:"business_authorization_letter_url" json:"business_authorization_letter_url"`
	// 证件正面图片url,调upload_wx接口获取（当为经办人时才填）
	ContactIdDocCopyUrl string `form:"contact_id_doc_copy_url" json:"contact_id_doc_copy_url"`
	// 证件背面图片url,调upload_wx接口获取（当为经办人时才填）,护照不填该字段
	ContactIdDocCopyBackUrl string `form:"contact_id_doc_copy_back_url" json:"contact_id_doc_copy_back_url"`

	// 联系人电话 必填
	MobilePhone string `form:"mobile_phone" json:"mobile_phone"`
	// 联系人邮箱 必填
	ContactEmail string `form:"contact_email" json:"contact_email"`
}

type CompanyWxAccountApplyBody struct {

	//主体资料 必填
	SubjectInfo CompanyWxSubjectInfo `form:"subject_info" json:"subject_info"`
	// 经营资料 必填
	BusinessInfo CompanyWxBusinessInfo `form:"business_info" json:"business_info"`
	// 银行账号资料 必填
	BankAccountInfo CompanyWxBankAccountInfo `form:"bank_account_info" json:"bank_account_info"`
	// 超管员资料 必填
	ContactInfo CompanyWxContactInfo `form:"contact_info" json:"contact_info"`
}

type CompanyWxAccountApplyRequest struct {
	base.Header
	CompanyWxAccountApplyBody
}

type CompanyWxAccountApplyResponse struct {
	base.Result
}

type CompanyWxAccountListQuery struct {
	Page     int64 `form:"page"`
	PageSize int64 `form:"page_size"`
}
type CompanyWxAccountListRequest struct {
	base.Header
	CompanyWxAccountListQuery
}

type CompanyWxAccountListResponse struct {
	base.Result
	Data pb_v1.CompanyWxAccountApplyListReply `json:"data"`
}

type CompanyWxAccountApplyInfoQuery struct {
	Id int64 `form:"id"`
}

type CompanyWxAccountApplyInfoRequest struct {
	base.Header
	CompanyWxAccountApplyInfoQuery
}

type CompanyWxAccountApplyInfoResponse struct {
	base.Result
	Data pb_v1.CompanyWxAccountApplyInfoReply `json:"data"`
}

type TemplateQuery struct {
	TemplateType int32 `form:"template_type" json:"template_type"`
}

type TemplateRequest struct {
	base.Header
	TemplateQuery
}

type TemplateData struct {
	Url string `json:"url"`
}

type TemplateResponse struct {
	base.Result
	Data TemplateData `json:"data"`
}

type CompanyStatisticRequest struct {
	base.Header
}

type CompanyStatisticResponse struct {
	base.Result
	Data pb_v1.CompanyStatisticReply `json:"data"`
}
