package v1

import (
	"property-company-gateway/param/base"
	pb_v1 "property-company-gateway/pb/v1"
)

type CompanyAddGardenBody struct {
	// 省
	Province     string `form:"province" json:"province"`
	ProvinceCode string `form:"province_code" json:"province_code"`
	// 市
	City     string `form:"city" json:"city"`
	CityCode string `form:"city_code" json:"city_code"`
	// 区
	Area     string `form:"area" json:"area"`
	AreaCode string `form:"area_code" json:"area_code"`
	// 街道
	Street     string `form:"street" json:"street"`
	StreetCode string `form:"street_code" json:"street_code"`
	// 社区
	Committee     string `form:"committee" json:"committee"`
	CommitteeCode string `form:"committee_code" json:"committee_code"`
	// 小区名字
	GardenName string `form:"garden_name" json:"garden_name"`
	// 小区地址
	GardenAddr string `form:"garden_addr" json:"garden_addr"`
	// 物业联系人
	PropertyPerson string `form:"property_person" json:"property_person"`
	// 物业联系人手机号
	PropertyPhone string `form:"property_phone" json:"property_phone"`
	// 小区形象图片
	GardenPic string `form:"garden_pic" json:"garden_pic"`
	// 小区描述
	GardenDesc string `form:"garden_desc" json:"garden_desc"`
	// 经度
	Lnt float64 `form:"lnt" json:"lnt"`
	// 纬度
	Lat float64 `form:"lat" json:"lat"`
	// 证明材料
	Appendix []string `form:"appendix" json:"appendix"`
	// 套餐订单id
	OrderId int64 `form:"order_id" json:"order_id"`

	// 1塔楼 2 板楼 3 塔板结合 4 其他
	BuildingType int32 `form:"building_type" json:"building_type"`
	// 建成年份开始时间戳
	BuildingStart int64 `form:"building_start" json:"building_start"`
	// 建成年份结束时间戳
	BuildingEnd int64 `form:"building_end" json:"building_end"`
	// 绿化率
	GreenPercent float64 `form:"green_percent" json:"green_percent"`
	// 容积率
	AreaPercent float64 `form:"area_percent" json:"area_percent"`
	// 车位配比
	SpaceInfo string `form:"space_info" json:"space_info"`
	// 占地面积
	CoveredArea float64 `form:"covered_area" json:"covered_area"`
	// 建筑面积
	BuildingArea float64 `form:"building_area" json:"building_area"`
	// 小区图片
	GardenPics []string `form:"garden_pics" json:"garden_pics"`
	// 开发企业
	BuildingCompany string `form:"building_company" json:"building_company"`
	// 总户数
	HouseTotal int64 `form:"house_total" json:"house_total"`
	// 固定车位数
	SpaceTotal int64 `form:"space_total" json:"space_total"`
	// 物业费开始，单位分
	PropertyFeeStart int64 `form:"property_fee_start" json:"property_fee_start"`
	// 物业费结束， 单位分
	PropertyFeeEnd int64 `form:"property_fee_end" json:"property_fee_end"`
	// 水费类型多选 1 民用 2 商用
	WaterType []int32 `form:"water_type" json:"water_type"`
	// 电费类型多选 1 民用 2 商用
	ElectricType []int32 `form:"electric_type" json:"electric_type"`
	// 燃气费开始，单位分
	GasFeeStart int64 `form:"gas_fee_start" json:"gas_fee_start"`
	// 燃气费开始，单位分
	GasFeeEnd int64 `form:"gas_fee_end" json:"gas_fee_end"`
	AvgPrice  int64 `form:"avg_price" json:"avg_price"`
}
type CompanyAddGardenRequest struct {
	base.Header
	CompanyAddGardenBody
}

type CompanyAddGardenResponse struct {
	base.Result
	Data pb_v1.CompanyAddGardenReply `json:"data"`
}

type CompanyGardenListQuery struct {
	Page        int64  `form:"page"`
	PageSize    int64  `form:"page_size" json:"page_size"`
	NotApproved bool   `form:"not_approved" json:"not_approved"`
	GardenName  string `form:"garden_name" json:"garden_name"`
}
type CompanyGardenListRequest struct {
	base.Header
	CompanyGardenListQuery
}

type CompanyGardenListResponse struct {
	base.Result
	Data pb_v1.GardenListReply `json:"data"`
}

type CompanyGardenDelQuery struct {
	Id int64 `form:"id" json:"id"`
}

type CompanyGardenDelRequest struct {
	base.Header
	CompanyGardenDelQuery
}

type CompanyGardenDelResponse struct {
	base.Result
}

type CompanyGardenUpdateBody struct {
	// 省
	//Province     string `form:"province" json:"province"`
	//ProvinceCode string `form:"province_code" json:"province_code"`
	// 市
	//City     string `form:"city" json:"city"`
	//CityCode string `form:"city_code" json:"city_code"`
	// 区
	//Area     string `form:"area" json:"area"`
	//AreaCode string `form:"area_code" json:"area_code"`
	// 街道
	//Street     string `form:"street" json:"street"`
	//StreetCode string `form:"street_code" json:"street_code"`
	// 社区
	//Committee     string `form:"committee" json:"committee"`
	//CommitteeCode string `form:"committee_code" json:"committee_code"`
	// 小区名字
	//GardenName string `form:"garden_name" json:"garden_name"`
	// 小区地址
	GardenAddr string `form:"garden_addr" json:"garden_addr"`
	// 物业联系人
	PropertyPerson string `form:"property_person" json:"property_person"`
	// 物业联系人手机号
	PropertyPhone string `form:"property_phone" json:"property_phone"`
	Id            int64  `form:"id" json:"id"`
	// 小区形象图片
	GardenPic string `form:"garden_pic" json:"garden_pic"`
	// 小区描述
	GardenDesc string `form:"garden_desc" json:"garden_desc"`
	// 经度
	Lnt float64 `form:"lnt"`
	// 纬度
	Lat float64 `form:"lat"`

	// 1塔楼 2 板楼 3 塔板结合 4 其他
	BuildingType int32 `form:"building_type" json:"building_type"`
	// 建成年份开始时间戳
	BuildingStart int64 `form:"building_start" json:"building_start"`
	// 建成年份结束时间戳
	BuildingEnd int64 `form:"building_end" json:"building_end"`
	// 绿化率
	GreenPercent float64 `form:"green_percent" json:"green_percent"`
	// 容积率
	AreaPercent float64 `form:"area_percent" json:"area_percent"`
	// 车位配比
	SpaceInfo string `form:"space_info" json:"space_info"`
	// 占地面积
	CoveredArea float64 `form:"covered_area" json:"covered_area"`
	// 建筑面积
	BuildingArea float64 `form:"building_area" json:"building_area"`
	// 小区图片
	GardenPics []string `form:"garden_pics" json:"garden_pics"`
	// 开发企业
	BuildingCompany string `form:"building_company" json:"building_company"`
	// 总户数
	HouseTotal int64 `form:"house_total" json:"house_total"`
	// 固定车位数
	SpaceTotal int64 `form:"space_total" json:"space_total"`
	// 物业费开始，单位分
	PropertyFeeStart int64 `form:"property_fee_start" json:"property_fee_start"`
	// 物业费结束， 单位分
	PropertyFeeEnd int64 `form:"property_fee_end" json:"property_fee_end"`
	// 水费类型多选 1 民用 2 商用
	WaterType []int32 `form:"water_type" json:"water_type"`
	// 电费类型多选 1 民用 2 商用
	ElectricType []int32 `form:"electric_type" json:"electric_type"`
	// 燃气费开始，单位分
	GasFeeStart int64 `form:"gas_fee_start" json:"gas_fee_start"`
	// 燃气费开始，单位分
	GasFeeEnd int64 `form:"gas_fee_end" json:"gas_fee_end"`

	AvgPrice int64 `form:"avg_price" json:"avg_price"`
}

type CompanyGardenUpdateRequest struct {
	base.Header
	CompanyGardenUpdateBody
}

type CompanyGardenUpdateResponse struct {
	base.Result
}

type CompanyEnterGardenQuery struct {
	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type CompanyEnterGardenRequest struct {
	base.Header
	CompanyEnterGardenQuery
}

type CompanyEnterGardenData struct {
	Token string `json:"token"`
}

type CompanyEnterGardenResponse struct {
	base.Result
	Data CompanyEnterGardenData `json:"data"`
}

type GardenKeyInfoChangeBody struct {
	// 省
	Province     string `form:"province" json:"province"`
	ProvinceCode string `form:"province_code" json:"province_code"`
	// 市
	City     string `form:"city" json:"city"`
	CityCode string `form:"city_code" json:"city_code"`
	// 区
	Area     string `form:"area" json:"area"`
	AreaCode string `form:"area_code" json:"area_code"`
	// 街道
	Street     string `form:"street" json:"street"`
	StreetCode string `form:"street_code" json:"street_code"`
	// 社区
	Committee     string `form:"committee" json:"committee"`
	CommitteeCode string `form:"committee_code" json:"committee_code"`
	// 小区名字
	GardenName string `form:"garden_name" json:"garden_name"`

	GardenId int64 `form:"garden_id" json:"garden_id"`
}

type GardenKeyInfoChangeRequest struct {
	base.Header
	GardenKeyInfoChangeBody
}

type GardenKeyInfoChangeResponse struct {
	base.Result
}

type GardenKeyInfoChangeListQuery struct {
	Page     int64 `form:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	Status   int32 `form:"status" json:"status"`
}
type GardenKeyInfoChangeListRequest struct {
	base.Header
	GardenKeyInfoChangeListQuery
}

type GardenKeyInfoChangeListResponse struct {
	base.Result
	Data pb_v1.GardenKeyInfoChangeListReply `json:"data"`
}

type CompanyCanAddGardenRequest struct {
	base.Header
}
type CompanyCanAddGardenResponse struct {
	base.Result
	Data pb_v1.CompanyCanAddGardenReply `json:"data"`
}
