// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"property-company-gateway/param/base"
	pb_v1 "property-company-gateway/pb/v1"
)

type LoginBody struct {
	User     string `form:"user"`
	Password string `form:"password"`
}

type LoginRequest struct {
	base.Header
	LoginBody
}

type LoginData struct {
	Uid   int64  `json:"uid"`
	Token string `json:"token"`
	User  string `json:"user"`
}

type LoginResponse struct {
	base.Result
	Data LoginData `json:"data"`
}

type TokenRequest struct {
	base.Header
}

type TokenResponse struct {
	base.Result
	Data         string `json:"data"`
	RefreshToken string `json:"refresh_token"`
}

type ResetePasswdResponse struct {
	base.Result
}

type GetVcodeQuery struct {
	Phone string `form:"phone"`
}
type GetVcodeRequest struct {
	GetVcodeQuery
}

type GetVcodeResponse struct {
	base.Result
	Data pb_v1.GetVcodeReply `json:"data"`
}

type LoginByPhoneBody struct {
	// 短信验证码
	Vcode uint32 `form:"vcode"`
	Phone string `form:"phone"`
}

type LoginByPhoneRequest struct {
	base.Header
	LoginByPhoneBody
}

type LoginByPhoneResponse struct {
	base.Result
	Data LoginData `json:"data"`
}

type ResetPasswordBody struct {
	Phone string `form:"phone" json:"phone"`
	// 短信验证码
	Vcode    uint32 `form:"vcode" json:"vcode"`
	Password string `form:"password" json:"password"`
}

type ResetPasswordRequest struct {
	ResetPasswordBody
}

type ResetPasswordResponse struct {
	base.Result
}

type ChangePasswordBody struct {
	OldPassword string `form:"old_password" json:"old_password"`
	NewPassword string `form:"new_password" json:"new_password"`
}

type ChangePasswordRequest struct {
	base.Header
	ChangePasswordBody
}

type ChangePasswordResponse struct {
	base.Result
}

type CompanyUserAddBody struct {
	UserName string `form:"user_name" json:"user_name"`
	Password string `form:"password" json:"password"`
	Email    string `form:"email" json:"email"`
	Phone    string `form:"phone" json:"phone"`
	RealName string `form:"real_name" json:"real_name"`
}

type CompanyUserAddRequest struct {
	base.Header
	CompanyUserAddBody
}

type CompanyUserAddResponse struct {
	base.Result
	Data pb_v1.CompanyUserAddReply `json:"data"`
}
type CompanyUserUpdateBody struct {
	UserName string `form:"user_name" json:"user_name"`
	Password string `form:"password" json:"password"`
	Email    string `form:"email" json:"email"`
	Phone    string `form:"phone" json:"phone"`
	Id       int64  `form:"id"`
	RealName string `form:"real_name" json:"real_name"`
}
type CompanyUserUpdateRequest struct {
	base.Header
	CompanyUserUpdateBody
}

type CompanyUserUpdateResponse struct {
	base.Result
}

type CompanyUserDelQuery struct {
	Id int64 `form:"id"`
}

type CompanyUserDelRequest struct {
	base.Header
	CompanyUserDelQuery
}

type CompanyUserDelResponse struct {
	base.Result
}

type CompanyUserListQuery struct {
	Page     int64 `form:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type CompanyUserListRequest struct {
	base.Header
	CompanyUserListQuery
}

type CompanyUserListResponse struct {
	base.Result
	Data pb_v1.CompanyUserListReply `json:"data"`
}
